Maintenance operations for the memory substrate.
Provides cleanup, compaction, vacuum, and statistical query operations used by the gorilla execution engine (Data Sweeper, Report Generator, etc.).
Maintenance operations for the memory substrate.
Provides cleanup, compaction, vacuum, and statistical query operations used by the gorilla execution engine (Data Sweeper, Report Generator, etc.).